//
//  ViewController.swift
//  MapboxTest
//
//  Created by Steffen Ryll on 12.09.18.
//  Copyright © 2018 Graphmasters GmbH. All rights reserved.
//

import Mapbox
import UIKit

final class ViewController: UIViewController {
    override func viewDidLoad() {
        super.viewDidLoad()

        let location = CLLocationCoordinate2D(latitude: 52.412253, longitude: 9.632462)
        mapView.camera = MGLMapCamera(lookingAtCenter: location, acrossDistance: 600, pitch: 60, heading: 210)
    }

    @IBOutlet weak var mapView: MGLMapView!
}

extension ViewController: MGLMapViewDelegate {
    func mapViewDidFinishLoadingMap(_ mapView: MGLMapView) {
        let jsonPath = Bundle.main.path(forResource: "route", ofType: "json")
        let data = try! Data(contentsOf: URL(fileURLWithPath: jsonPath!))
        let coordinates = try! JSONDecoder().decode([Coordinate].self, from: data)
            .map { CLLocationCoordinate2D(latitude: $0.latitude, longitude: $0.longitude) }
        let polyline = MGLPolylineFeature(coordinates: coordinates, count: UInt(coordinates.count))
        let source = MGLShapeSource(identifier: "route", shape: polyline, options: [.lineDistanceMetrics: true])

        let layer = MGLLineStyleLayer(identifier: "route", source: source)
        layer.sourceLayerIdentifier = "route"
        layer.lineWidth = NSExpression(
            format: "mgl_interpolate:withCurveType:parameters:stops:($zoomLevel, 'exponential', 1.5, %@)", [14: 4, 18: 40])
        layer.lineGradient = NSExpression(
            format: "mgl_interpolate:withCurveType:parameters:stops:($lineProgress, 'linear', nil, %@)", [0: UIColor.red, 1: UIColor.blue])
        layer.lineCap = NSExpression(forConstantValue: "round")

        mapView.style?.addSource(source)
        mapView.style?.addLayer(layer)
    }
}

struct Coordinate: Codable {
    let latitude: Double
    let longitude: Double
}
